==> RsSmw-4.90.49.49-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Nr5G/Node/CarMapping/Cell/Row.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Row:
	"""Row commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: RowNull, default value after init: RowNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("row", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_rowNull_get', 'repcap_rowNull_set', repcap.RowNull.Nr0)

	def repcap_rowNull_set(self, enum_value: repcap.RowNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to RowNull.Default
		Default value after init: RowNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_rowNull_get(self) -> repcap.RowNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, map_cell_num: int, rowNull=repcap.RowNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CARMapping:CELL:[ROW<CH0>] \n
		Snippet: driver.source.bb.nr5G.node.carMapping.cell.row.set(map_cell_num = 1, rowNull = repcap.RowNull.Default) \n
		Queries which of the carriers is output at which baseband. \n
			:param map_cell_num: integer Indicates the carrier. Carriers are numbered automatically, where the maximum number of carriers is set with the command [:SOURcehw]:BB:NR5G:NODE:NCARrier. The number of available carriers and their default mapping to the available basebands depends on the selected system configuration. Range: 0 to 15
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')"""
		param = Conversions.decimal_value_to_str(map_cell_num)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CARMapping:CELL:ROW{rowNull_cmd_val} {param}')

	def get(self, rowNull=repcap.RowNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CARMapping:CELL:[ROW<CH0>] \n
		Snippet: value: int = driver.source.bb.nr5G.node.carMapping.cell.row.get(rowNull = repcap.RowNull.Default) \n
		Queries which of the carriers is output at which baseband. \n
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: map_cell_num: integer Indicates the carrier. Carriers are numbered automatically, where the maximum number of carriers is set with the command [:SOURcehw]:BB:NR5G:NODE:NCARrier. The number of available carriers and their default mapping to the available basebands depends on the selected system configuration. Range: 0 to 15"""
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CARMapping:CELL:ROW{rowNull_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'Row':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Row(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group

==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Nr5G/Node/CarMapping/Cell/Row.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Row:
	"""Row commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: RowNull, default value after init: RowNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("row", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_rowNull_get', 'repcap_rowNull_set', repcap.RowNull.Nr0)

	def repcap_rowNull_set(self, rowNull: repcap.RowNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to RowNull.Default
		Default value after init: RowNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(rowNull)

	def repcap_rowNull_get(self) -> repcap.RowNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, map_cell_num: int, rowNull=repcap.RowNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CARMapping:CELL:[ROW<CH0>] \n
		Snippet: driver.source.bb.nr5G.node.carMapping.cell.row.set(map_cell_num = 1, rowNull = repcap.RowNull.Default) \n
		Queries which of the carriers is output at which baseband. \n
			:param map_cell_num: integer Indicates the carrier. Carriers are numbered automatically, where the maximum number of carriers is set with the command [:SOURcehw]:BB:NR5G:NODE:NCARrier. The number of available carriers and their default mapping to the available basebands depends on the selected system configuration. Range: 0 to 15
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
		"""
		param = Conversions.decimal_value_to_str(map_cell_num)
		rowNull_cmd_val = self._cmd_group.get_repcap_cmd_value(rowNull, repcap.RowNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CARMapping:CELL:ROW{rowNull_cmd_val} {param}')

	def get(self, rowNull=repcap.RowNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CARMapping:CELL:[ROW<CH0>] \n
		Snippet: value: int = driver.source.bb.nr5G.node.carMapping.cell.row.get(rowNull = repcap.RowNull.Default) \n
		Queries which of the carriers is output at which baseband. \n
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: map_cell_num: integer Indicates the carrier. Carriers are numbered automatically, where the maximum number of carriers is set with the command [:SOURcehw]:BB:NR5G:NODE:NCARrier. The number of available carriers and their default mapping to the available basebands depends on the selected system configuration. Range: 0 to 15"""
		rowNull_cmd_val = self._cmd_group.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CARMapping:CELL:ROW{rowNull_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'Row':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Row(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
